<?php
/*
Plugin Name: M-PLAYER
Plugin URI: https://mytubepress.com/store/m-player/
Description: Ultimate HTML5 Video Player plugin for WordPress, compatible with all themes owned by mytubepress.com, This plugin is a great software if you want to use in-stream video advertisements. Activate and then go to your MPLAYER Settings page to set up ad spaces, colors and more.
Author: Alberto Pilotto
Version: 1.1.0
Author URI: http://mytubepress.com
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
require_once 'app/bootstrap.php';

// this is the URL our updater / license checker pings. This should be the URL of the site with EDD installed
define( 'MPLAYER_FREE_STORE_URL', 'http://mytubepress.com' ); // you should use your own CONSTANT name, and be sure to replace it throughout this file
define( 'MPLAYER_FREE_ITEM_NAME', 'M-PLAYER' );
// the download ID for the product in Easy Digital Downloads
define( 'MPLAYER_FREE_ITEM_ID', 50576 ); // you should use your own CONSTANT name, and be sure to replace it throughout this file
// the name of the settings page for the license input to be displayed
define( 'MPLAYER_FREE_PLUGIN_LICENSE_PAGE', 'mpl_license_verification' );

if( !class_exists( 'MPL_Plugin_Updater' ) ) {
 // load our custom updater
 include( dirname( __FILE__ ) . '/app/updater/MPL_Plugin_Updater.php' );
}

function mpl_free_plugin_updater() {

 // retrieve our license key from the DB
 $license_key = trim( get_option( 'magicplayer_license_key' ) );

 // setup the updater
 $edd_updater = new MPL_Plugin_Updater( MPLAYER_FREE_STORE_URL, __FILE__,
	 array(
		 'version' => '1.1.0', // current version number
		 'license' => $license_key, // license key (used get_option above to retrieve from DB)
		 'item_id' => MPLAYER_FREE_ITEM_ID, // ID of the product
		 'author'  => 'Alberto Pilotto', // author of this plugin
		 'beta'    => false,
	 )
 );

}
add_action( 'admin_init', 'mpl_free_plugin_updater', 0 );

function mplay_active() {
		add_option('mplay_license_key', 'c93297ba3a09714bfbb95a0dcbe456af');
	  add_option('mplay_license_key_status', 'valid');
		//activate license
	  wp_remote_post('https://mytubepress.com/?edd_action=activate_license&item_id=50576&license=c93297ba3a09714bfbb95a0dcbe456af&url='.home_url() );

}
add_action( 'activated_plugin', 'mplay_active' );

function edd_mplay_activate_license() {
	   // check if the license is valid
	      $license = 'c93297ba3a09714bfbb95a0dcbe456af';

	      // data to send in our API request
	      $api_params = array(
	         'edd_action' => 'activate_license',
	         'license'    => $license,
	         'item_name'  => urlencode( MPLAYER_FREE_ITEM_NAME ), // the name of our product in EDD
	         'url'        => home_url()
	      );

	      // Call the custom API.
	      $response = wp_remote_post( MPLAYER_FREE_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

	      // make sure the response came back okay
	      if ( ! is_wp_error( $response ) && 200 === wp_remote_retrieve_response_code( $response ) ) {
	         $license_data = json_decode( wp_remote_retrieve_body( $response ) );
	         // $license_data->license will be either "valid" or "invalid"
	         update_option( 'mplay_license_status', $license_data->license );
	      }

	}
add_action( 'admin_init', 'edd_mplay_activate_license' );
add_action( 'activated_plugin', 'edd_mplay_activate_license' );

/************************************
* the code below is just a standard
* options page. Substitute with
* your own.
*************************************/

function magicplayer_license_menu() {
 add_submenu_page( 'MPLAYER License', 'MPLAYER License', 'manage_options', MPLAYER_FREE_PLUGIN_LICENSE_PAGE, 'magicplayer_license_page' );
}
add_action('admin_menu', 'magicplayer_license_menu');

function magicplayer_license_page() {
 $license = 'c93297ba3a09714bfbb95a0dcbe456af';
 $status  = get_option( 'magicplayer_license_status' );
 ?>
 <div class="wrap">
	 <h2><?php _e('MPLAYER License Key'); ?></h2>
	 <form method="post" action="options.php">

		 <?php settings_fields('magicplayer_license'); ?>

		 <table class="form-table">
			 <tbody>
				 <tr valign="top">
					 <th scope="row" valign="top">
						 <?php _e('MPLAYER License Key'); ?>
					 </th>
					 <td>
						 <input id="magicplayer_license_key" name="magicplayer_license_key" type="text" class="regular-text" placeholder="<?php esc_attr_e( $license ); ?>" value="<?php esc_attr_e( $license ); ?>" />
						 <?php if( false == $license ) { ?>
						 <label class="description" for="magicplayer_license_key"><?php _e('Paste your license key and press enter. '); ?></label>
						 <?php } ?>
					 </td>
				 </tr>
				 <?php if( false !== $license ) { ?>
					 <tr valign="top">
						 <th scope="row" valign="top">
							 <?php _e('Activate License'); ?>
						 </th>
						 <td>
							 <?php if( $status !== false && $status == 'valid' ) { ?>
								 <span style="color:green;padding:10px 6px 8px 0;margin-top:5px;font-size: 20px;"><?php _e('License Activated'); ?></span>
								 <?php wp_nonce_field( 'magicplayer_nonce', 'magicplayer_nonce' ); ?>
								 <input type="submit" class="button-secondary" name="mplf_license_deactivate" value="<?php _e('Deactivate License'); ?>"/>
							 <?php } else {
								 wp_nonce_field( 'magicplayer_nonce', 'magicplayer_nonce' ); ?>
								 <span style="display:none;"><?php submit_button(); ?></span> <input type="submit" class="button-secondary" name="mplf_license_activate" value="<?php _e('Activate License'); ?>"/>
							 <?php } ?>
						 </td>
					 </tr>
				 <?php } ?>
			 </tbody>
		 </table>

	 </form>
 <?php
}

function magicplayer_register_option() {
 // creates our settings in the options table
 register_setting('magicplayer_license', 'magicplayer_license_key', 'magicplayer_sanitize_license' );
}
add_action('admin_init', 'magicplayer_register_option');

function magicplayer_sanitize_license( $new ) {
 $old = get_option( 'magicplayer_license_key' );
 if( $old && $old != $new ) {
	 delete_option( 'magicplayer_license_status' ); // new license has been entered, so must reactivate
 }
 return $new;
}



/************************************
* this illustrates how to activate
* a license key
*************************************/

function magicplayer_activate_license() {

 // listen for our activate button to be clicked
 if( isset( $_POST['mplf_license_activate'] ) ) {

	 // run a quick security check
	 if( ! check_admin_referer( 'magicplayer_nonce', 'magicplayer_nonce' ) )
		 return; // get out if we didn't click the Activate button

	 // retrieve the license from the database
	 $license = 'c93297ba3a09714bfbb95a0dcbe456af';


	 // data to send in our API request
	 $api_params = array(
		 'edd_action' => 'activate_license',
		 'license'    => $license,
		 'item_name'  => urlencode( MPLAYER_FREE_ITEM_NAME ), // the name of our product in EDD
		 'url'        => home_url()
	 );

	 // Call the custom API.
	 $response = wp_remote_post( MPLAYER_FREE_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

	 // make sure the response came back okay
	 if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

		 if ( is_wp_error( $response ) ) {
			 $message = $response->get_error_message();
		 } else {
			 $message = __( 'An error occurred, please try again.' );
		 }

	 } else {

		 $license_data = json_decode( wp_remote_retrieve_body( $response ) );

		 if ( false === $license_data->success ) {

			 switch( $license_data->error ) {

				 case 'expired' :

					 $message = sprintf(
						 __( 'Your license key expired on %s.' ),
						 date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) )
					 );
					 break;

				 case 'disabled' :
				 case 'revoked' :

					 $message = __( 'Your license key has been disabled.' );
					 break;

				 case 'missing' :

					 $message = __( 'Invalid license.' );
					 break;

				 case 'invalid' :
				 case 'site_inactive' :

					 $message = __( 'Your license is not active for this URL.' );
					 break;

				 case 'item_name_mismatch' :

					 $message = sprintf( __( 'This appears to be an invalid license key for %s.' ), MPLAYER_FREE_ITEM_NAME );
					 break;

				 case 'no_activations_left':

					 $message = __( 'Your license key has reached its activation limit.' );
					 break;

				 default :

					 $message = __( 'An error occurred, please try again.' );
					 break;
			 }

		 }

	 }

	 // Check if anything passed on a message constituting a failure
	 if ( ! empty( $message ) ) {
		 $base_url = admin_url( 'plugins.php?page=' . MPLAYER_FREE_PLUGIN_LICENSE_PAGE );
		 $redirect = add_query_arg( array( 'sl_activation' => 'false', 'message' => urlencode( $message ) ), $base_url );

		 wp_redirect( $redirect );
		 exit();
	 }

	 // $license_data->license will be either "valid" or "invalid"

	 update_option( 'magicplayer_license_status', $license_data->license );
	 wp_redirect( admin_url( 'plugins.php?page=' . MPLAYER_FREE_PLUGIN_LICENSE_PAGE ) );
	 exit();
 }
}
add_action('admin_init', 'magicplayer_activate_license');


/***********************************************
* Illustrates how to deactivate a license key.
* This will decrease the site count
***********************************************/

function magicplayer_deactivate_license() {

 // listen for our activate button to be clicked
 if( isset( $_POST['mplf_license_deactivate'] ) ) {

	 // run a quick security check
	 if( ! check_admin_referer( 'magicplayer_nonce', 'magicplayer_nonce' ) )
		 return; // get out if we didn't click the Activate button

	 // retrieve the license from the database
	 $license = trim( get_option( 'magicplayer_license_key' ) );


	 // data to send in our API request
	 $api_params = array(
		 'edd_action' => 'deactivate_license',
		 'license'    => $license,
		 'item_name'  => urlencode( MPLAYER_FREE_ITEM_NAME ), // the name of our product in EDD
		 'url'        => home_url()
	 );

	 // Call the custom API.
	 $response = wp_remote_post( MPLAYER_FREE_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

	 // make sure the response came back okay
	 if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {

		 if ( is_wp_error( $response ) ) {
			 $message = $response->get_error_message();
		 } else {
			 $message = __( 'An error occurred, please try again.' );
		 }

		 $base_url = admin_url( 'plugins.php?page=' . MPLAYER_FREE_PLUGIN_LICENSE_PAGE );
		 $redirect = add_query_arg( array( 'sl_activation' => 'false', 'message' => urlencode( $message ) ), $base_url );

		 wp_redirect( $redirect );
		 exit();
	 }

	 // decode the license data
	 $license_data = json_decode( wp_remote_retrieve_body( $response ) );

	 // $license_data->license will be either "deactivated" or "failed"
	 if( $license_data->license == 'deactivated' ) {
		 delete_option( 'magicplayer_license_status' );
	 }

	 wp_redirect( admin_url( 'plugins.php?page=' . MPLAYER_FREE_PLUGIN_LICENSE_PAGE ) );
	 exit();

 }
}
add_action('admin_init', 'magicplayer_deactivate_license');


/************************************
* this illustrates how to check if
* a license key is still valid
* the updater does this for you,
* so this is only needed if you
* want to do something custom
*************************************/

function magicplayer_check_license() {

 global $wp_version;

 $license = trim( get_option( 'magicplayer_license_key' ) );

 $api_params = array(
	 'edd_action' => 'check_license',
	 'license' => $license,
	 'item_name' => urlencode( MPLAYER_FREE_ITEM_NAME ),
	 'url'       => home_url()
 );

 // Call the custom API.
 $response = wp_remote_post( MPLAYER_FREE_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

 if ( is_wp_error( $response ) )
	 return false;

 $license_data = json_decode( wp_remote_retrieve_body( $response ) );

 if( $license_data->license == 'valid' ) {
	 echo 'valid'; exit;
	 // this license is still valid
 } else {
	 echo 'invalid'; exit;
	 // this license is no longer valid
 }
}

/**
 * This is a means of catching errors from the activation method above and displaying it to the customer
 */
function magicplayer_admin_notices() {
 if ( isset( $_GET['sl_activation'] ) && ! empty( $_GET['message'] ) ) {

	 switch( $_GET['sl_activation'] ) {

		 case 'false':
			 $message = urldecode( $_GET['message'] );
			 ?>
			 <div class="error">
				 <p><?php echo $message; ?></p>
			 </div>
			 <?php
			 break;

		 case 'true':
		 default:
			 // Developers can put a custom success message here for when activation is successful if they way.
			 break;

	 }
 }
}
add_action( 'admin_notices', 'magicplayer_admin_notices' );

//end

$tmpl_opt  = plugin_dir_path( __FILE__ ) . '/admin/option/option.php';
//$mn_icon  = plugins_url().'/m-play/app/public/img/mplayicon.png';
$plugin_options = new VP_Option(array(
	'is_dev_mode'           => false,                                  // dev mode, default to false
	'option_key'            => 'mytubepress',                           // options key in db, required
	'page_slug'             => 'magicplayer_options',                    // options page slug, required
	'template'              => $tmpl_opt,                              // template file path or array, required
	'menu_page'             =>  array(
  'icon_url' => 'dashicons-video-alt3',
  'position' => 100,
  ),
	'use_auto_group_naming' => true,
	'use_exim_menu'         => false,
	'minimum_role'          => 'edit_theme_options',
	'layout'                => 'fixed',
	'page_title'            => __( 'MPLAYER', 'magicplayer' ),
	'menu_label'            => __( 'MPLAYER', 'magicplayer' ),
));
function mytubepress( $name ) {
		return vp_option( "mytubepress." . $name );
}
include 'app/player/fluidplayer/FluidPlayerPlugin.php';
FluidPlayerPlugin::init();
include( plugin_dir_path( __FILE__ ) . 'app/extra_functions.php');

function mplayer_add_settings_link( $links ) {
    $settings_link = '<a href="admin.php?page=magicplayer_options">' . __( 'Settings' ) . '</a> | <a target="_blank" href="https://mytubepress.com/forums/forum/plugins/m-player/">' . __( 'Support' ) . '</a>';
    array_push( $links, $settings_link );
  	return $links;
}
$plugin = plugin_basename( __FILE__ );
add_filter( "plugin_action_links_$plugin", 'mplayer_add_settings_link' );
